==> Products.TinyMCE-1.1rc12.zip: Products.TinyMCE-1.1rc12/Products/TinyMCE/skins/tinymce/plugins/table/langs/ch_dlg.js <==
tinyMCE.addI18n('ch.table_dlg',{
general_tab:"\u4E00\u822C",
advanced_tab:"\u9AD8\u7EA7",
general_props:"\u4E00\u822C\u5C5E\u6027",
advanced_props:"\u9AD8\u7EA7\u5C5E\u6027",
rowtype:"\u884C\u6240\u5728\u7684\u8868\u683C\u4F4D\u7F6E",
title:"\u63D2\u5165/\u7F16\u8F91\u8868\u683C",
width:"\u5BBD\u5EA6",
height:"\u9AD8\u5EA6",
cols:"\u5217\u6570",
rows:"\u884C\u6570",
cellspacing:"\u50A8\u5B58\u683C\u95F4\u8DDD",
cellpadding:"\u50A8\u5B58\u683C\u7559\u767D",
border:"\u8FB9\u6846",
align:"\u5BF9\u9F50\u65B9\u5F0F",
align_default:"\u9884\u8BBE",
align_left:"\u9760\u5DE6",
align_right:"\u9760\u53F3",
align_middle:"\u5C45\u4E2D",
row_title:"\u884C\u5C5E\u6027",
cell_title:"\u50A8\u5B58\u683C\u5C5E\u6027",
cell_type:"\u50A8\u5B58\u683C\u522B",
valign:"\u6C34\u51C6\u5BF9\u9F50\u65B9\u5F0F",
align_top:"\u4E0A\u65B9",
align_bottom:"\u4E0B\u65B9",
bordercolor:"\u8FB9\u6846\u989C\u8272",
bgcolor:"\u80CC\u666F\u989C\u8272",
merge_cells_title:"\u5408\u5E76\u50A8\u5B58\u683C",
id:"Id",
style:"\u6837\u5F0F",
langdir:"\u8BED\u8A00\u4E66\u5199\u65B9\u5411",
langcode:"\u8BED\u8A00\u7F16\u7801",
mime:"\u76EE\u6807MIME\u7C7B\u578B",
ltr:"\u7531\u5DE6\u5230\u53F3",
rtl:"\u7531\u53F3\u5230\u5DE6",
bgimage:"\u80CC\u666F\u56FE\u7247",
summary:"\u6982\u8981",
td:"\u6570\u636E",
th:"\u8868\u5934",
cell_cell:"\u66F4\u65B0\u6240\u7684\u50A8\u5B58\u683C",
cell_row:"\u66F4\u65B0\u6240\u5728\u884C\u7684\u5168\u90E8\u50A8\u5B58\u683C",
cell_all:"\u66F4\u65B0\u8868\u683C\u5185\u7684\u5168\u90E8\u50A8\u5B58\u683C",
row_row:"\u66F4\u65B0\u6240\u5728\u884C",
row_odd:"\u66F4\u65B0\u8868\u683C\u5185\u7684\u5947\u6570\u884C",
row_even:"\u66F4\u65B0\u8868\u683C\u5185\u7684\u5076\u6570\u884C",
row_all:"\u66F4\u65B0\u8868\u683C\u5185\u5168\u90E8\u884C",
thead:"\u8868\u5934",
tbody:"\u8868\u8EAB",
tfoot:"\u8868\u5C3E",
scope:"\u8303\u56F4",
rowgroup:"\u884C\u7FA4\u7EC4",
colgroup:"\u5217\u7FA4\u7EC4",
col_limit:"\u5DF2\u8D85\u8FC7\u53EF\u7528\u6570\uFF0C\u6700\u9AD8\u7684\u5217\u6570\u4E3A{$cols}\u5217\u3002",
row_limit:"\u5DF2\u8D85\u8FC7\u53EF\u7528\u6570\uFF0C\u6700\u9AD8\u7684\u884C\u6570\u4E3A{$rows}\u884C\u3002",
cell_limit:"\u5DF2\u8D85\u8FC7\u53EF\u7528\u6570\uFF0C\u6700\u9AD8\u7684\u50A8\u5B58\u683C\u6570\u4E3A{$cells}\u683C\u3002",
missing_scope:"\u6807\u9898\u884C\u7F3A\u5931\uFF01",
caption:"\u8868\u683C\u6807\u9898",
frame:"\u8FB9\u6846",
frame_none:"\u65E0",
frame_groups:"\u7FA4\u7EC4",
frame_rows:"\u884C",
frame_cols:"\u5217",
frame_all:"\u5168\u90E8",
rules:"\u7EBF\u6761",
rules_void:"\u7A7A",
rules_above:"\u4E0A",
rules_below:"\u4E0B",
rules_hsides:"\u6C34\u51C6\u8FB9",
rules_lhs:"\u5DE6\u8FB9",
rules_rhs:"\u53F3\u8FB9",
rules_vsides:"\u5782\u76F4\u8FB9",
rules_box:"\u76D2\u578B",
rules_border:"\u5916\u6846"
});

==> Products.TinyMCE-1.2.4.zip: Products.TinyMCE-1.2.4/Products/TinyMCE/skins/tinymce/plugins/table/langs/ch_dlg.js <==
tinyMCE.addI18n('ch.table_dlg',{
general_tab:"\u4E00\u822C",
advanced_tab:"\u9AD8\u7EA7",
general_props:"\u4E00\u822C\u5C5E\u6027",
advanced_props:"\u9AD8\u7EA7\u5C5E\u6027",
rowtype:"\u884C\u6240\u5728\u7684\u8868\u683C\u4F4D\u7F6E",
title:"\u63D2\u5165/\u7F16\u8F91\u8868\u683C",
width:"\u5BBD\u5EA6",
height:"\u9AD8\u5EA6",
cols:"\u5217\u6570",
rows:"\u884C\u6570",
cellspacing:"\u5355\u5143\u683C\u95F4\u8DDD",
cellpadding:"\u5355\u5143\u683C\u7559\u767D",
border:"\u8FB9\u6846",
align:"\u5BF9\u9F50\u65B9\u5F0F",
align_default:"\u9884\u8BBE",
align_left:"\u9760\u5DE6",
align_right:"\u9760\u53F3",
align_middle:"\u5C45\u4E2D",
row_title:"\u884C\u5C5E\u6027",
cell_title:"\u5355\u5143\u683C\u5C5E\u6027",
cell_type:"\u5355\u5143\u683C\u522B",
valign:"\u6C34\u5E73\u5BF9\u9F50",
align_top:"\u4E0A\u65B9",
align_bottom:"\u4E0B\u65B9",
bordercolor:"\u8FB9\u6846\u989C\u8272",
bgcolor:"\u80CC\u666F\u989C\u8272",
merge_cells_title:"\u5408\u5E76\u5355\u5143\u683C",
id:"Id",
style:"\u6837\u5F0F",
langdir:"\u8BED\u8A00\u4E66\u5199\u65B9\u5411",
langcode:"\u8BED\u8A00\u7F16\u7801",
mime:"\u76EE\u6807MIME\u7C7B\u578B",
ltr:"\u7531\u5DE6\u5230\u53F3",
rtl:"\u7531\u53F3\u5230\u5DE6",
bgimage:"\u80CC\u666F\u56FE\u7247",
summary:"\u6982\u8981",
td:"\u6570\u636E",
th:"\u8868\u5934",
cell_cell:"\u66F4\u65B0\u6240\u7684\u5355\u5143\u683C",
cell_row:"\u66F4\u65B0\u6240\u5728\u884C\u7684\u5168\u90E8\u5355\u5143\u683C",
cell_all:"\u66F4\u65B0\u8868\u683C\u5185\u7684\u5168\u90E8\u5355\u5143\u683C",
row_row:"\u66F4\u65B0\u6240\u5728\u884C",
row_odd:"\u66F4\u65B0\u8868\u683C\u5185\u7684\u5947\u6570\u884C",
row_even:"\u66F4\u65B0\u8868\u683C\u5185\u7684\u5076\u6570\u884C",
row_all:"\u66F4\u65B0\u8868\u683C\u5185\u5168\u90E8\u884C",
thead:"\u8868\u5934",
tbody:"\u8868\u8EAB",
tfoot:"\u8868\u5C3E",
scope:"\u8303\u56F4",
rowgroup:"\u884C\u7FA4\u7EC4",
colgroup:"\u5217\u7FA4\u7EC4",
col_limit:"\u5DF2\u8D85\u8FC7\u53EF\u7528\u6570\uFF0C\u6700\u9AD8\u7684\u5217\u6570\u4E3A{$cols}\u5217\u3002",
row_limit:"\u5DF2\u8D85\u8FC7\u53EF\u7528\u6570\uFF0C\u6700\u9AD8\u7684\u884C\u6570\u4E3A{$rows}\u884C\u3002",
cell_limit:"\u5DF2\u8D85\u8FC7\u53EF\u7528\u6570\uFF0C\u6700\u9AD8\u7684\u5355\u5143\u683C\u6570\u4E3A{$cells}\u683C\u3002",
missing_scope:"\u6807\u9898\u884C\u7F3A\u5931\uFF01",
caption:"\u8868\u683C\u6807\u9898",
frame:"\u8FB9\u6846",
frame_none:"\u65E0",
frame_groups:"\u7FA4\u7EC4",
frame_rows:"\u884C",
frame_cols:"\u5217",
frame_all:"\u5168\u90E8",
rules:"\u7EBF\u6761",
rules_void:"\u7A7A",
rules_above:"\u4E0A",
rules_below:"\u4E0B",
rules_hsides:"\u6C34\u5E73\u8FB9",
rules_lhs:"\u5DE6\u8FB9",
rules_rhs:"\u53F3\u8FB9",
rules_vsides:"\u5782\u76F4\u8FB9",
rules_box:"\u76D2\u578B",
rules_border:"\u5916\u6846"
});
